int reqOrderInsert(const dict &req, int reqid);

int reqOrderAction(const dict &req, int reqid);

int reqLogin(const dict &req, int reqid);

int reqLogout(const dict &req, int reqid);

int reqUserPasswordUpdate(const dict &req, int reqid);

int reqTransferInsert(const dict &req, int reqid);

int reqFundPaybackInsert(const dict &req, int reqid);

int reqStockPaybackInsert(const dict &req, int reqid);

int reqLockInsert(const dict &req, int reqid);

int reqExecOrderInsert(const dict &req, int reqid);

int reqExecOrderAction(const dict &req, int reqid);

int reqQryInstrument(const dict &req, int reqid);

int reqQryDepthMarketData(const dict &req, int reqid);

int reqQryInvestorPosition(const dict &req, int reqid);

int reqQryTradingAccount(const dict &req, int reqid);

int reqQryOrder(const dict &req, int reqid);

int reqQryTrade(const dict &req, int reqid);

int reqQryOptionInstrMarginByVolume(const dict &req, int reqid);

int reqQryOptionInstrCommRate(const dict &req, int reqid);

int reqQryInstrumentCommissionRate(const dict &req, int reqid);

int reqQryInvestor(const dict &req, int reqid);

int reqQryTransfer(const dict &req, int reqid);

int reqQryTradingCode(const dict &req, int reqid);

int reqQryMaxOrderVolume(const dict &req, int reqid);

int reqQryCreditInstrument(const dict &req, int reqid);

int reqQryCreditInvestor(const dict &req, int reqid);

int reqQryPrivateCreditStock(const dict &req, int reqid);

int reqQryCreditConcentration(const dict &req, int reqid);

int reqQryCreditFundDetail(const dict &req, int reqid);

int reqQryCreditStockDetail(const dict &req, int reqid);

int reqQryFundPayback(const dict &req, int reqid);

int reqQryStockPayback(const dict &req, int reqid);

int reqQryPublicCreditFund(const dict &req, int reqid);

int reqQryETFInfo(const dict &req, int reqid);

int reqQryETFComponent(const dict &req, int reqid);

int reqQryCreditAvailableDetail(const dict &req, int reqid);

int reqQryLock(const dict &req, int reqid);

int reqQryExecOrder(const dict &req, int reqid);

int reqQryLockPosition(const dict &req, int reqid);

int reqQryOptPosiLimit(const dict &req, int reqid);

int reqQryOptAmountLimit(const dict &req, int reqid);

