void processRspSubL2MarketData(Task *task);

void processRspUnSubL2MarketData(Task *task);

void processRspSubL2OrderAndTrade(Task *task);

void processRspUnSubL2OrderAndTrade(Task *task);

void processRspSubL2IndexMarketData(Task *task);

void processRspUnSubL2IndexMarketData(Task *task);

void processRtnL2MarketData(Task *task);

void processRtnL2IndexMarketData(Task *task);

void processRtnL2Order(Task *task);

void processRtnL2Trade(Task *task);

