#ifndef __H_DNT_NAMESPACE_H__
#define __H_DNT_NAMESPACE_H__

#define _DNT_NS_	_DNT_
#define _DNT_NS_BEGIN_ namespace _DNT_{
#define _DNT_NS_END_	}
#define _USING_DNT_NS_	using namespace _DNT_;

#endif // __H_DNT_NAMESPACE_H__
