#define ONRSPSUBL2MARKETDATA 0
#define ONRSPUNSUBL2MARKETDATA 1
#define ONRSPSUBL2ORDERANDTRADE 2
#define ONRSPUNSUBL2ORDERANDTRADE 3
#define ONRSPSUBL2INDEXMARKETDATA 4
#define ONRSPUNSUBL2INDEXMARKETDATA 5
#define ONRTNL2MARKETDATA 6
#define ONRTNL2INDEXMARKETDATA 7
#define ONRTNL2ORDER 8
#define ONRTNL2TRADE 9
