.def("reqOrderInsert", &TdApi::reqOrderInsert)
.def("reqOrderAction", &TdApi::reqOrderAction)
.def("reqLogin", &TdApi::reqLogin)
.def("reqLogout", &TdApi::reqLogout)
.def("reqUserPasswordUpdate", &TdApi::reqUserPasswordUpdate)
.def("reqTransferInsert", &TdApi::reqTransferInsert)
.def("reqFundPaybackInsert", &TdApi::reqFundPaybackInsert)
.def("reqStockPaybackInsert", &TdApi::reqStockPaybackInsert)
.def("reqLockInsert", &TdApi::reqLockInsert)
.def("reqExecOrderInsert", &TdApi::reqExecOrderInsert)
.def("reqExecOrderAction", &TdApi::reqExecOrderAction)
.def("reqQryInstrument", &TdApi::reqQryInstrument)
.def("reqQryDepthMarketData", &TdApi::reqQryDepthMarketData)
.def("reqQryInvestorPosition", &TdApi::reqQryInvestorPosition)
.def("reqQryTradingAccount", &TdApi::reqQryTradingAccount)
.def("reqQryOrder", &TdApi::reqQryOrder)
.def("reqQryTrade", &TdApi::reqQryTrade)
.def("reqQryOptionInstrMarginByVolume", &TdApi::reqQryOptionInstrMarginByVolume)
.def("reqQryOptionInstrCommRate", &TdApi::reqQryOptionInstrCommRate)
.def("reqQryInstrumentCommissionRate", &TdApi::reqQryInstrumentCommissionRate)
.def("reqQryInvestor", &TdApi::reqQryInvestor)
.def("reqQryTransfer", &TdApi::reqQryTransfer)
.def("reqQryTradingCode", &TdApi::reqQryTradingCode)
.def("reqQryMaxOrderVolume", &TdApi::reqQryMaxOrderVolume)
.def("reqQryCreditInstrument", &TdApi::reqQryCreditInstrument)
.def("reqQryCreditInvestor", &TdApi::reqQryCreditInvestor)
.def("reqQryPrivateCreditStock", &TdApi::reqQryPrivateCreditStock)
.def("reqQryCreditConcentration", &TdApi::reqQryCreditConcentration)
.def("reqQryCreditFundDetail", &TdApi::reqQryCreditFundDetail)
.def("reqQryCreditStockDetail", &TdApi::reqQryCreditStockDetail)
.def("reqQryFundPayback", &TdApi::reqQryFundPayback)
.def("reqQryStockPayback", &TdApi::reqQryStockPayback)
.def("reqQryPublicCreditFund", &TdApi::reqQryPublicCreditFund)
.def("reqQryETFInfo", &TdApi::reqQryETFInfo)
.def("reqQryETFComponent", &TdApi::reqQryETFComponent)
.def("reqQryCreditAvailableDetail", &TdApi::reqQryCreditAvailableDetail)
.def("reqQryLock", &TdApi::reqQryLock)
.def("reqQryExecOrder", &TdApi::reqQryExecOrder)
.def("reqQryLockPosition", &TdApi::reqQryLockPosition)
.def("reqQryOptPosiLimit", &TdApi::reqQryOptPosiLimit)
.def("reqQryOptAmountLimit", &TdApi::reqQryOptAmountLimit)

.def("onFrontConnected", &TdApi::onFrontConnected)
.def("onFrontDisconnected", &TdApi::onFrontDisconnected)
.def("onRspError", &TdApi::onRspError)
.def("onRtnOrder", &TdApi::onRtnOrder)
.def("onRtnTrade", &TdApi::onRtnTrade)
.def("onErrRtnOrderAction", &TdApi::onErrRtnOrderAction)
.def("onRspOrderInsert", &TdApi::onRspOrderInsert)
.def("onRspOrderAction", &TdApi::onRspOrderAction)
.def("onRspLogin", &TdApi::onRspLogin)
.def("onRspUserPasswordUpdate", &TdApi::onRspUserPasswordUpdate)
.def("onRspTransferInsert", &TdApi::onRspTransferInsert)
.def("onRtnTransfer", &TdApi::onRtnTransfer)
.def("onRspFundPaybackInsert", &TdApi::onRspFundPaybackInsert)
.def("onRtnFundPayback", &TdApi::onRtnFundPayback)
.def("onRspStockPaybackInsert", &TdApi::onRspStockPaybackInsert)
.def("onRtnStockPayback", &TdApi::onRtnStockPayback)
.def("onRtnPrivateCreditStock", &TdApi::onRtnPrivateCreditStock)
.def("onRtnLock", &TdApi::onRtnLock)
.def("onRspLockInsert", &TdApi::onRspLockInsert)
.def("onRtnExecOrder", &TdApi::onRtnExecOrder)
.def("onRspExecOrderInsert", &TdApi::onRspExecOrderInsert)
.def("onRspExecOrderAction", &TdApi::onRspExecOrderAction)
.def("onErrRtnExecOrderAction", &TdApi::onErrRtnExecOrderAction)
.def("onRspQryInstrument", &TdApi::onRspQryInstrument)
.def("onRspQryDepthMarketData", &TdApi::onRspQryDepthMarketData)
.def("onRspQryInvestorPosition", &TdApi::onRspQryInvestorPosition)
.def("onRspQryTradingAccount", &TdApi::onRspQryTradingAccount)
.def("onRspQryOptionInstrMarginByVolume", &TdApi::onRspQryOptionInstrMarginByVolume)
.def("onRspQryOptionInstrCommRate", &TdApi::onRspQryOptionInstrCommRate)
.def("onRspQryOrder", &TdApi::onRspQryOrder)
.def("onRspQryTrade", &TdApi::onRspQryTrade)
.def("onRspQryInstrumentCommissionRate", &TdApi::onRspQryInstrumentCommissionRate)
.def("onRspQryInvestor", &TdApi::onRspQryInvestor)
.def("onRspQryTransfer", &TdApi::onRspQryTransfer)
.def("onRspQryTradingCode", &TdApi::onRspQryTradingCode)
.def("onRspQryMaxOrderVolume", &TdApi::onRspQryMaxOrderVolume)
.def("onRspQryCreditInstrument", &TdApi::onRspQryCreditInstrument)
.def("onRspQryCreditInvestor", &TdApi::onRspQryCreditInvestor)
.def("onRspQryPrivateCreditStock", &TdApi::onRspQryPrivateCreditStock)
.def("onRspQryCreditConcentration", &TdApi::onRspQryCreditConcentration)
.def("onRspQryCreditFundDetail", &TdApi::onRspQryCreditFundDetail)
.def("onRspQryCreditStockDetail", &TdApi::onRspQryCreditStockDetail)
.def("onRspQryFundPayback", &TdApi::onRspQryFundPayback)
.def("onRspQryStockPayback", &TdApi::onRspQryStockPayback)
.def("onRspQryPublicCreditFund", &TdApi::onRspQryPublicCreditFund)
.def("onRspQryETFInfo", &TdApi::onRspQryETFInfo)
.def("onRspQryETFComponent", &TdApi::onRspQryETFComponent)
.def("onRspQryCreditAvailableDetail", &TdApi::onRspQryCreditAvailableDetail)
.def("onRspQryLock", &TdApi::onRspQryLock)
.def("onRspQryExecOrder", &TdApi::onRspQryExecOrder)
.def("onRspQryLockPosition", &TdApi::onRspQryLockPosition)
.def("onRspQryOptPosiLimit", &TdApi::onRspQryOptPosiLimit)
.def("onRspQryOptAmountLimit", &TdApi::onRspQryOptAmountLimit)
;
