virtual void onRspSubL2MarketData(const dict &data) {};

virtual void onRspUnSubL2MarketData(const dict &data) {};

virtual void onRspSubL2OrderAndTrade(const dict &data) {};

virtual void onRspUnSubL2OrderAndTrade(const dict &data) {};

virtual void onRspSubL2IndexMarketData(const dict &data) {};

virtual void onRspUnSubL2IndexMarketData(const dict &data) {};

virtual void onRtnL2MarketData(const dict &data) {};

virtual void onRtnL2IndexMarketData(const dict &data) {};

virtual void onRtnL2Order(const dict &data) {};

virtual void onRtnL2Trade(const dict &data) {};

