#define ONFRONTCONNECTED 0
#define ONFRONTDISCONNECTED 1
#define ONRSPERROR 2
#define ONRTNORDER 3
#define ONRTNTRADE 4
#define ONERRRTNORDERACTION 5
#define ONRSPORDERINSERT 6
#define ONRSPORDERACTION 7
#define ONRSPLOGIN 8
#define ONRSPUSERPASSWORDUPDATE 9
#define ONRSPTRANSFERINSERT 10
#define ONRTNTRANSFER 11
#define ONRSPFUNDPAYBACKINSERT 12
#define ONRTNFUNDPAYBACK 13
#define ONRSPSTOCKPAYBACKINSERT 14
#define ONRTNSTOCKPAYBACK 15
#define ONRTNPRIVATECREDITSTOCK 16
#define ONRTNLOCK 17
#define ONRSPLOCKINSERT 18
#define ONRTNEXECORDER 19
#define ONRSPEXECORDERINSERT 20
#define ONRSPEXECORDERACTION 21
#define ONERRRTNEXECORDERACTION 22
#define ONRSPQRYINSTRUMENT 23
#define ONRSPQRYDEPTHMARKETDATA 24
#define ONRSPQRYINVESTORPOSITION 25
#define ONRSPQRYTRADINGACCOUNT 26
#define ONRSPQRYOPTIONINSTRMARGINBYVOLUME 27
#define ONRSPQRYOPTIONINSTRCOMMRATE 28
#define ONRSPQRYORDER 29
#define ONRSPQRYTRADE 30
#define ONRSPQRYINSTRUMENTCOMMISSIONRATE 31
#define ONRSPQRYINVESTOR 32
#define ONRSPQRYTRANSFER 33
#define ONRSPQRYTRADINGCODE 34
#define ONRSPQRYMAXORDERVOLUME 35
#define ONRSPQRYCREDITINSTRUMENT 36
#define ONRSPQRYCREDITINVESTOR 37
#define ONRSPQRYPRIVATECREDITSTOCK 38
#define ONRSPQRYCREDITCONCENTRATION 39
#define ONRSPQRYCREDITFUNDDETAIL 40
#define ONRSPQRYCREDITSTOCKDETAIL 41
#define ONRSPQRYFUNDPAYBACK 42
#define ONRSPQRYSTOCKPAYBACK 43
#define ONRSPQRYPUBLICCREDITFUND 44
#define ONRSPQRYETFINFO 45
#define ONRSPQRYETFCOMPONENT 46
#define ONRSPQRYCREDITAVAILABLEDETAIL 47
#define ONRSPQRYLOCK 48
#define ONRSPQRYEXECORDER 49
#define ONRSPQRYLOCKPOSITION 50
#define ONRSPQRYOPTPOSILIMIT 51
#define ONRSPQRYOPTAMOUNTLIMIT 52
