SECURITY_DNT_TP_NonTrade = '0'
SECURITY_DNT_TP_Bidding = '1'
SECURITY_DNT_TP_Continuous = '2'
SECURITY_DNT_TP_Suspension = '3'
SECURITY_DNT_TP_Fuse = '4'
SECURITY_DNT_TP_RecovFuse = '5'
SECURITY_DNT_TP_UnrecovFuse = '6'
SECURITY_DNT_TP_BiddingOver = '7'
SECURITY_DNT_TP_TempSuspension = '8'

UT_ICT_EID = '0'
UT_ICT_IDCard = '1'
UT_ICT_OfficerIDCard = '2'
UT_ICT_PoliceIDCard = '3'
UT_ICT_SoldierIDCard = '4'
UT_ICT_HouseholdRegister = '5'
UT_ICT_Passport = '6'
UT_ICT_TaiwanCompatriotIDCard = '7'
UT_ICT_HomeComingCard = '8'
UT_ICT_LicenseNo = '9'
UT_ICT_TaxNo = 'A'
UT_ICT_HMMainlandTravelPermit = 'B'
UT_ICT_TwMainlandTravelPermit = 'C'
UT_ICT_DrivingLicense = 'D'
UT_ICT_SocialID = 'F'
UT_ICT_LocalID = 'G'
UT_ICT_BusinessRegistration = 'H'
UT_ICT_HKMCIDCard = 'I'
UT_ICT_AccountsPermits = 'J'
UT_ICT_OtherCard = 'x'
UT_IR_All = '1'
UT_IR_Group = '2'
UT_IR_Single = '3'
UT_DR_All = '1'
UT_DR_Group = '2'
UT_DR_Single = '3'
UT_DS_Asynchronous = '1'
UT_DS_Synchronizing = '2'
UT_DS_Synchronized = '3'
UT_BDS_Synchronized = '1'
UT_BDS_Synchronizing = '2'
UT_ECS_NoConnection = '1'
UT_ECS_QryInstrumentSent = '2'
UT_ECS_GotInformation = '9'
UT_TCS_NotConnected = '1'
UT_TCS_Connected = '2'
UT_TCS_QryInstrumentSent = '3'
UT_TCS_SubPrivateFlow = '4'
UT_FC_DataAsync = '1'
UT_BFC_SyncBrokerData = '1'
UT_BFC_DeleteOrder = '2'
UT_BFC_OrderInsert = '3'
UT_BFC_Designate = '4'
UT_BFC_Transfer = '5'
UT_BFC_SyncTransfer = '6'
UT_OAS_Submitted = 'a'
UT_OAS_Accepted = 'b'
UT_OAS_Rejected = 'c'
UT_OST_AllTraded = '0'
UT_OST_PartTradedQueueing = '1'
UT_OST_PartTradedNotQueueing = '2'
UT_OST_NoTradeQueueing = '3'
UT_OST_NoTradeNotQueueing = '4'
UT_OST_Canceled = '5'
UT_OST_Unknown = 'a'
UT_OST_NotTouched = 'b'
UT_OST_Touched = 'c'
UT_OSS_InsertSubmitted = '0'
UT_OSS_CancelSubmitted = '1'
UT_OSS_ModifySubmitted = '2'
UT_OSS_Accepted = '3'
UT_OSS_InsertRejected = '4'
UT_OSS_CancelRejected = '5'
UT_OSS_ModifyRejected = '6'
UT_PSD_Today = '1'
UT_PSD_History = '2'
UT_PDT_UseHistory = '1'
UT_PDT_NoUseHistory = '2'
UT_ER_Broker = '1'
UT_ER_Host = '2'
UT_ER_Maker = '3'
UT_PC_Futures = '1'
UT_PC_Options = '2'
UT_PC_Combination = '3'
UT_PC_Spot = '4'
UT_PC_EFP = '5'
UT_PC_SpotOption = '6'
UT_PC_ETFOption = '7'
UT_PC_Stock = '8'
UT_IP_NotStart = '0'
UT_IP_Started = '1'
UT_IP_Pause = '2'
UT_IP_Expired = '3'
UT_D_Buy = '0'
UT_D_Sell = '1'
UT_PT_Net = '1'
UT_PT_Gross = '2'
UT_PD_Net = '1'
UT_PD_Long = '2'
UT_PD_Short = '3'
UT_SS_NonActive = '1'
UT_SS_Startup = '2'
UT_SS_Operating = '3'
UT_SS_Settlement = '4'
UT_SS_SettlementFinished = '5'
UT_RA_Trade = '0'
UT_RA_Settlement = '1'
UT_HF_Speculation = '1'
UT_HF_Arbitrage = '2'
UT_HF_Hedge = '3'
UT_HF_Covered = '4'
UT_HF_MarketMaker = '5'
UT_HF_Redemption = 'A'
UT_HF_Credit = 'B'
UT_HF_Collateral = 'C'
UT_BHF_Speculation = '1'
UT_BHF_Arbitrage = '2'
UT_BHF_Hedge = '3'
UT_CIDT_Speculation = '1'
UT_CIDT_Arbitrage = '2'
UT_CIDT_Hedge = '3'
UT_CIDT_MarketMaker = '5'
UT_CIDT_Credit = 'B'
UT_OPT_AnyPrice = '1'
UT_OPT_LimitPrice = '2'
UT_OPT_BestPrice = '3'
UT_OPT_LastPrice = '4'
UT_OPT_LastPricePlusOneTicks = '5'
UT_OPT_LastPricePlusTwoTicks = '6'
UT_OPT_LastPricePlusThreeTicks = '7'
UT_OPT_AskPrice1 = '8'
UT_OPT_AskPrice1PlusOneTicks = '9'
UT_OPT_AskPrice1PlusTwoTicks = 'A'
UT_OPT_AskPrice1PlusThreeTicks = 'B'
UT_OPT_BidPrice1 = 'C'
UT_OPT_BidPrice1PlusOneTicks = 'D'
UT_OPT_BidPrice1PlusTwoTicks = 'E'
UT_OPT_BidPrice1PlusThreeTicks = 'F'
UT_OPT_FiveLevelPrice = 'G'
UT_OPT_BestPriceThisSide = 'H'
UT_OF_Open = '0'
UT_OF_Close = '1'
UT_OF_ForceClose = '2'
UT_OF_CloseToday = '3'
UT_OF_CloseYesterday = '4'
UT_OF_ForceOff = '5'
UT_OF_LocalForceClose = '6'
UT_FCC_NotForceClose = '0'
UT_FCC_LackDeposit = '1'
UT_FCC_ClientOverPositionLimit = '2'
UT_FCC_MemberOverPositionLimit = '3'
UT_FCC_NotMultiple = '4'
UT_FCC_Violation = '5'
UT_FCC_Other = '6'
UT_FCC_PersonDeliv = '7'
UT_ORDT_Normal = '0'
UT_ORDT_DeriveFromQuote = '1'
UT_ORDT_DeriveFromCombination = '2'
UT_ORDT_Combination = '3'
UT_ORDT_ConditionalOrder = '4'
UT_ORDT_Swap = '5'
UT_ORDT_NewStock = '7'
UT_ORDT_CRP = 'Z'
UT_ORDT_Bond = 'B'
UT_TC_IOC = '1'
UT_TC_GFS = '2'
UT_TC_GFD = '3'
UT_TC_GTD = '4'
UT_TC_GTC = '5'
UT_TC_GFA = '6'
UT_VC_AV = '1'
UT_VC_MV = '2'
UT_VC_CV = '3'
UT_CC_Immediately = '1'
UT_CC_Touch = '2'
UT_CC_TouchProfit = '3'
UT_CC_ParkedOrder = '4'
UT_CC_LastPriceGreaterThanStopPrice = '5'
UT_CC_LastPriceGreaterEqualStopPrice = '6'
UT_CC_LastPriceLesserThanStopPrice = '7'
UT_CC_LastPriceLesserEqualStopPrice = '8'
UT_CC_AskPriceGreaterThanStopPrice = '9'
UT_CC_AskPriceGreaterEqualStopPrice = 'A'
UT_CC_AskPriceLesserThanStopPrice = 'B'
UT_CC_AskPriceLesserEqualStopPrice = 'C'
UT_CC_BidPriceGreaterThanStopPrice = 'D'
UT_CC_BidPriceGreaterEqualStopPrice = 'E'
UT_CC_BidPriceLesserThanStopPrice = 'F'
UT_CC_BidPriceLesserEqualStopPrice = 'H'
UT_AF_Delete = '0'
UT_AF_Modify = '3'
UT_TR_Allow = '0'
UT_TR_CloseOnly = '1'
UT_TR_Forbidden = '2'
UT_OSRC_Participant = '0'
UT_OSRC_Administrator = '1'
UT_TRDT_SplitCombination = '#'
UT_TRDT_Common = '0'
UT_TRDT_OptionsExecution = '1'
UT_TRDT_OTC = '2'
UT_TRDT_EFPDerived = '3'
UT_TRDT_CombinationDerived = '4'
UT_TRDT_ETFComponent = '5'
UT_TRDT_ETFMoney = '6'
UT_PSRC_LastPrice = '0'
UT_PSRC_Buy = '1'
UT_PSRC_Sell = '2'
UT_IS_BeforeTrading = '0'
UT_IS_AuctionOrdering = '1'
UT_IS_AuctionMatch = '2'
UT_IS_Continous = '3'
UT_IS_NoTrading = '4'
UT_IS_ClosingAuction = '5'
UT_IS_Closed = '6'
UT_IS_Pause = 'a'
UT_IS_RecoverableFusing = 'b'
UT_IS_UnrecoverableFusing = 'c'
UT_IS_Interrupt = 'd'
UT_IS_PostTransaction = 'e'
UT_IER_Automatic = '1'
UT_IER_Manual = '2'
UT_IER_Fuse = '3'
UT_BS_NoUpload = '1'
UT_BS_Uploaded = '2'
UT_BS_Failed = '3'
UT_RS_All = '1'
UT_RS_ByProduct = '2'
UT_RP_ByVolume = '1'
UT_RP_ByFeeOnHand = '2'
UT_RL_Level1 = '1'
UT_RL_Level2 = '2'
UT_RL_Level3 = '3'
UT_RL_Level4 = '4'
UT_RL_Level5 = '5'
UT_RL_Level6 = '6'
UT_RL_Level7 = '7'
UT_RL_Level8 = '8'
UT_RL_Level9 = '9'
UT_RSD_ByPeriod = '1'
UT_RSD_ByStandard = '2'
UT_MT_Out = '0'
UT_MT_In = '1'
UT_ISPI_MortgageRatio = '4'
UT_ISPI_MarginWay = '5'
UT_ISPI_BillDeposit = '9'
UT_ESPI_MortgageRatio = '1'
UT_ESPI_OtherFundItem = '2'
UT_ESPI_OtherFundImport = '3'
UT_ESPI_CFFEXMinPrepa = '6'
UT_ESPI_CZCESettlementType = '7'
UT_ESPI_ExchDelivFeeMode = '9'
UT_ESPI_DelivFeeMode = '0'
UT_ESPI_CZCEComMarginType = 'A'
UT_ESPI_DceComMarginType = 'B'
UT_ESPI_OptOutDisCountRate = 'a'
UT_ESPI_OptMiniGuarantee = 'b'
UT_SPI_InvestorIDMinLength = '1'
UT_SPI_AccountIDMinLength = '2'
UT_SPI_UserRightLogon = '3'
UT_SPI_SettlementBillTrade = '4'
UT_SPI_TradingCode = '5'
UT_SPI_CheckFund = '6'
UT_SPI_CommModelRight = '7'
UT_SPI_MarginModelRight = '9'
UT_SPI_IsStandardActive = '8'
UT_SPI_UploadSettlementFile = 'U'
UT_SPI_DownloadCSRCFile = 'D'
UT_SPI_SettlementBillFile = 'S'
UT_SPI_CSRCOthersFile = 'C'
UT_SPI_InvestorPhoto = 'P'
UT_SPI_CSRCData = 'R'
UT_SPI_InvestorPwdModel = 'I'
UT_SPI_CFFEXInvestorSettleFile = 'F'
UT_SPI_InvestorIDType = 'a'
UT_SPI_FreezeMaxReMain = 'r'
UT_SPI_IsSync = 'A'
UT_SPI_RelieveOpenLimit = 'O'
UT_SPI_IsStandardFreeze = 'X'
UT_SPI_CZCENormalProductHedge = 'B'
UT_TPID_UserSessionLimit = 1
UT_TPID_UserLoginFailedLimit = 2
UT_TPID_IPLoginFailedLimit = 3
UT_TPID_Auth = 4
UT_TPID_STLimit = 5
UT_TPID_STLimitSZSE = 6
UT_TPID_SystemName = 7
UT_TPID_OptAvailRatio = 8
UT_FI_SettlementFund = 'F'
UT_FI_Trade = 'T'
UT_FI_InvestorPosition = 'P'
UT_FI_SubEntryFund = 'O'
UT_FI_CZCECombinationPos = 'C'
UT_FI_CSRCData = 'R'
UT_FI_CZCEClose = 'L'
UT_FI_CZCENoClose = 'N'
UT_FI_PositionDtl = 'D'
UT_FI_OptionStrike = 'S'
UT_FI_SettlementPriceComparison = 'M'
UT_FI_NonTradePosChange = 'B'
UT_FUT_Settlement = '0'
UT_FUT_Check = '1'
UT_FFT_Txt = '0'
UT_FFT_Zip = '1'
UT_FFT_DBF = '2'
UT_FUS_SucceedUpload = '1'
UT_FUS_FailedUpload = '2'
UT_FUS_SucceedLoad = '3'
UT_FUS_PartSucceedLoad = '4'
UT_FUS_FailedLoad = '5'
UT_TD_Out = '0'
UT_TD_In = '1'
UT_SC_NoSpecialRule = '0'
UT_SC_NoSpringFestival = '1'
UT_IPT_LastSettlement = '1'
UT_IPT_LaseClose = '2'
UT_PLP_Active = '1'
UT_PLP_NonActive = '2'
UT_PLP_Canceled = '3'
UT_DM_CashDeliv = '1'
UT_DM_CommodityDeliv = '2'
UT_FIOT_FundIO = '1'
UT_FIOT_Transfer = '2'
UT_FIOT_SwapCurrency = '3'
UT_FT_Deposite = '1'
UT_FT_ItemFund = '2'
UT_FT_Company = '3'
UT_FT_InnerTransfer = '4'
UT_FD_In = '1'
UT_FD_Out = '2'
UT_FS_Record = '1'
UT_FS_Check = '2'
UT_FS_Charge = '3'
UT_PS_None = '1'
UT_PS_Publishing = '2'
UT_PS_Published = '3'
UT_ES_NonActive = '1'
UT_ES_Startup = '2'
UT_ES_Initialize = '3'
UT_ES_Initialized = '4'
UT_ES_Close = '5'
UT_ES_Closed = '6'
UT_ES_Settlement = '7'
UT_STS_Initialize = '0'
UT_STS_Settlementing = '1'
UT_STS_Settlemented = '2'
UT_STS_Finished = '3'
UT_CT_Person = '0'
UT_CT_Company = '1'
UT_CT_Fund = '2'
UT_CT_SpecialOrgan = '3'
UT_CT_Asset = '4'
UT_BT_Trade = '0'
UT_BT_TradeSettle = '1'
UT_FAS_Low = '1'
UT_FAS_Normal = '2'
UT_FAS_Focus = '3'
UT_FAS_Risk = '4'
UT_FAS_ByTrade = '1'
UT_FAS_ByDeliv = '2'
UT_FAS_None = '3'
UT_FAS_FixFee = '4'
UT_PWDT_Trade = '1'
UT_PWDT_Account = '2'
UT_AG_All = '1'
UT_AG_OnlyLost = '2'
UT_AG_OnlyGain = '3'
UT_AG_None = '4'
UT_ICP_Include = '0'
UT_ICP_NotInclude = '2'
UT_AWT_Enable = '0'
UT_AWT_Disable = '2'
UT_AWT_NoHoldEnable = '3'
UT_FPWD_UnCheck = '0'
UT_FPWD_Check = '1'
UT_TT_BankToSecurity = '0'
UT_TT_SecurityToBank = '1'
UT_TT_MainToThisSeat = '2'
UT_TT_ThisToMainSeat = '3'
UT_TT_ThisToOtherSeat = '4'
UT_TT_OtherToThisSeat = '5'
UT_TVF_Invalid = '0'
UT_TVF_Valid = '1'
UT_TVF_Reverse = '2'
UT_RN_CD = '0'
UT_RN_ZT = '1'
UT_RN_QT = '2'
UT_SEX_None = '0'
UT_SEX_Man = '1'
UT_SEX_Woman = '2'
UT_UT_Investor = '0'
UT_UT_Operator = '1'
UT_UT_SuperUser = '2'
UT_RATETYPE_MarginRate = '2'
UT_NOTETYPE_TradeSettleBill = '1'
UT_NOTETYPE_TradeSettleMonth = '2'
UT_NOTETYPE_CallMarginNotes = '3'
UT_NOTETYPE_ForceCloseNotes = '4'
UT_NOTETYPE_TradeNotes = '5'
UT_NOTETYPE_DelivNotes = '6'
UT_SBS_Day = '1'
UT_SBS_Volume = '2'
UT_ST_Day = '0'
UT_ST_Month = '1'
UT_URT_Logon = '1'
UT_URT_Transfer = '2'
UT_URT_EMail = '3'
UT_URT_Fax = '4'
UT_URT_ConditionOrder = '5'
UT_MPT_PreSettlementPrice = '1'
UT_MPT_SettlementPrice = '2'
UT_MPT_AveragePrice = '3'
UT_MPT_OpenPrice = '4'
UT_BGS_None = '0'
UT_BGS_NoGenerated = '1'
UT_BGS_Generated = '2'
UT_AT_HandlePositionAlgo = '1'
UT_AT_FindMarginRateAlgo = '2'
UT_HPA_Base = '1'
UT_HPA_DCE = '2'
UT_HPA_CZCE = '3'
UT_FMRA_Base = '1'
UT_FMRA_DCE = '2'
UT_FMRA_CZCE = '3'
UT_HTAA_Base = '1'
UT_HTAA_DCE = '2'
UT_HTAA_CZCE = '3'
UT_PST_Order = '1'
UT_PST_Open = '2'
UT_PST_Fund = '3'
UT_PST_Settlement = '4'
UT_PST_Company = '5'
UT_PST_Corporation = '6'
UT_PST_LinkMan = '7'
UT_PST_Ledger = '8'
UT_PST_Trustee = '9'
UT_PST_TrusteeCorporation = 'A'
UT_PST_TrusteeOpen = 'B'
UT_PST_TrusteeContact = 'C'
UT_PST_ForeignerRefer = 'D'
UT_PST_CorporationRefer = 'E'
UT_QIR_All = '1'
UT_QIR_Group = '2'
UT_QIR_Single = '3'
UT_IRS_Normal = '1'
UT_IRS_Warn = '2'
UT_IRS_Call = '3'
UT_IRS_Force = '4'
UT_IRS_Exception = '5'
UT_UET_Login = '1'
UT_UET_Logout = '2'
UT_UET_Trading = '3'
UT_UET_TradingError = '4'
UT_UET_UpdatePassword = '5'
UT_UET_Authenticate = '6'
UT_UET_Other = '9'
UT_ICS_Close = '0'
UT_ICS_CloseToday = '1'
UT_SM_Non = '0'
UT_SM_Instrument = '1'
UT_SM_Product = '2'
UT_SM_Investor = '3'
UT_PAOS_NotSend = '1'
UT_PAOS_Send = '2'
UT_PAOS_Deleted = '3'
UT_VDS_Dealing = '1'
UT_VDS_DeaclSucceed = '2'
UT_ORGS_Standard = '0'
UT_ORGS_ESunny = '1'
UT_ORGS_KingStarV6 = '2'
UT_VTS_NaturalDeal = '0'
UT_VTS_SucceedEnd = '1'
UT_VTS_FailedEND = '2'
UT_VTS_Exception = '3'
UT_VTS_ManualDeal = '4'
UT_VTS_MesException = '5'
UT_VTS_SysException = '6'
UT_VBAT_BankBook = '1'
UT_VBAT_BankCard = '2'
UT_VBAT_CreditCard = '3'
UT_VMS_Natural = '0'
UT_VMS_Canceled = '9'
UT_VAA_NoAvailAbility = '0'
UT_VAA_AvailAbility = '1'
UT_VAA_Repeal = '2'
UT_VTC_BankBankToFuture = '1'
UT_VTC_BankFutureToBank = '2'
UT_VTC_FutureBankToFuture = '3'
UT_VTC_FutureFutureToBank = '4'
UT_GEN_Program = '0'
UT_GEN_HandWork = '1'
UT_CFMMCKK_REQUEST = 'R'
UT_CFMMCKK_AUTO = 'A'
UT_CFMMCKK_MANUAL = 'M'
UT_CFT_IDCard = '0'
UT_CFT_Passport = '1'
UT_CFT_OfficerIDCard = '2'
UT_CFT_SoldierIDCard = '3'
UT_CFT_HomeComingCard = '4'
UT_CFT_HouseholdRegister = '5'
UT_CFT_LicenseNo = '6'
UT_CFT_InstitutionCodeCard = '7'
UT_CFT_TempLicenseNo = '8'
UT_CFT_NoEnterpriseLicenseNo = '9'
UT_CFT_OtherCard = 'x'
UT_CFT_SuperDepAgree = 'a'
UT_FBC_Others = '0'
UT_FBC_TransferDetails = '1'
UT_FBC_CustAccStatus = '2'
UT_FBC_AccountTradeDetails = '3'
UT_FBC_FutureAccountChangeInfoDetails = '4'
UT_FBC_CustMoneyDetail = '5'
UT_FBC_CustCancelAccountInfo = '6'
UT_FBC_CustMoneyResult = '7'
UT_FBC_OthersExceptionResult = '8'
UT_FBC_CustInterestNetMoneyDetails = '9'
UT_FBC_CustMoneySendAndReceiveDetails = 'a'
UT_FBC_CorporationMoneyTotal = 'b'
UT_FBC_MainbodyMoneyTotal = 'c'
UT_FBC_MainPartMonitorData = 'd'
UT_FBC_PreparationMoney = 'e'
UT_FBC_BankMoneyMonitorData = 'f'
UT_CEC_Exchange = '1'
UT_CEC_Cash = '2'
UT_YNI_Yes = '0'
UT_YNI_No = '1'
UT_BLT_CurrentMoney = '0'
UT_BLT_UsableMoney = '1'
UT_BLT_FetchableMoney = '2'
UT_BLT_FreezeMoney = '3'
UT_GD_Unknown = '0'
UT_GD_Male = '1'
UT_GD_Female = '2'
UT_FPF_BEN = '0'
UT_FPF_OUR = '1'
UT_FPF_SHA = '2'
UT_PWKT_ExchangeKey = '0'
UT_PWKT_PassWordKey = '1'
UT_PWKT_MACKey = '2'
UT_PWKT_MessageKey = '3'
UT_PWT_Query = '0'
UT_PWT_Fetch = '1'
UT_PWT_Transfer = '2'
UT_PWT_Trade = '3'
UT_EM_NoEncry = '0'
UT_EM_DES = '1'
UT_EM_3DES = '2'
UT_BRF_BankNotNeedRepeal = '0'
UT_BRF_BankWaitingRepeal = '1'
UT_BRF_BankBeenRepealed = '2'
UT_BRORF_BrokerNotNeedRepeal = '0'
UT_BRORF_BrokerWaitingRepeal = '1'
UT_BRORF_BrokerBeenRepealed = '2'
UT_TS_Bank = '0'
UT_TS_Future = '1'
UT_TS_Store = '2'
UT_LF_Yes = '0'
UT_LF_No = '1'
UT_BAS_Normal = '0'
UT_BAS_Freeze = '1'
UT_BAS_ReportLoss = '2'
UT_MAS_Normal = '0'
UT_MAS_Cancel = '1'
UT_MSS_Point = '0'
UT_MSS_PrePoint = '1'
UT_MSS_CancelPoint = '2'
UT_SYT_FutureBankTransfer = '0'
UT_SYT_StockBankTransfer = '1'
UT_SYT_TheThirdPartStore = '2'
UT_TEF_NormalProcessing = '0'
UT_TEF_Success = '1'
UT_TEF_Failed = '2'
UT_TEF_Abnormal = '3'
UT_TEF_ManualProcessedForException = '4'
UT_TEF_CommuFailedNeedManualProcess = '5'
UT_TEF_SysErrorNeedManualProcess = '6'
UT_PSS_NotProcess = '0'
UT_PSS_StartProcess = '1'
UT_PSS_Finished = '2'
UT_CUSTT_Person = '0'
UT_CUSTT_Institution = '1'
UT_FBTTD_FromBankToFuture = '1'
UT_FBTTD_FromFutureToBank = '2'
UT_OOD_Open = '1'
UT_OOD_Destroy = '0'
UT_AVAF_Invalid = '0'
UT_AVAF_Valid = '1'
UT_AVAF_Repeal = '2'
UT_OT_Bank = '1'
UT_OT_Future = '2'
UT_OT_PlateForm = '9'
UT_OL_HeadQuarters = '1'
UT_OL_Branch = '2'
UT_PID_FutureProtocal = '0'
UT_PID_ICBCProtocal = '1'
UT_PID_ABCProtocal = '2'
UT_PID_CBCProtocal = '3'
UT_PID_CCBProtocal = '4'
UT_PID_BOCOMProtocal = '5'
UT_PID_FBTPlateFormProtocal = 'X'
UT_CM_ShortConnect = '0'
UT_CM_LongConnect = '1'
UT_SRM_ASync = '0'
UT_SRM_Sync = '1'
UT_BAT_BankBook = '1'
UT_BAT_SavingCard = '2'
UT_BAT_CreditCard = '3'
UT_FAT_BankBook = '1'
UT_FAT_SavingCard = '2'
UT_FAT_CreditCard = '3'
UT_OS_Ready = '0'
UT_OS_CheckIn = '1'
UT_OS_CheckOut = '2'
UT_OS_CheckFileArrived = '3'
UT_OS_CheckDetail = '4'
UT_OS_DayEndClean = '5'
UT_OS_Invalid = '9'
UT_CCBFM_ByAmount = '1'
UT_CCBFM_ByMonth = '2'
UT_CAPIT_Client = '1'
UT_CAPIT_Server = '2'
UT_CAPIT_UserApi = '3'
UT_LS_Connected = '1'
UT_LS_Disconnected = '2'
UT_BPWDF_NoCheck = '0'
UT_BPWDF_BlankCheck = '1'
UT_BPWDF_EncryptCheck = '2'
UT_SAT_AccountID = '1'
UT_SAT_CardID = '2'
UT_SAT_SHStockholderID = '3'
UT_SAT_SZStockholderID = '4'
UT_TRFS_Submitted = 'a'
UT_TRFS_Accepted = 'b'
UT_TRFS_Rejected = 'c'
UT_TRFS_Canceled = 'd'
UT_SPTYPE_Broker = '0'
UT_SPTYPE_Bank = '1'
UT_REQRSP_Request = '0'
UT_REQRSP_Response = '1'
UT_FBTUET_SignIn = '0'
UT_FBTUET_FromBankToFuture = '1'
UT_FBTUET_FromFutureToBank = '2'
UT_FBTUET_OpenAccount = '3'
UT_FBTUET_CancelAccount = '4'
UT_FBTUET_ChangeAccount = '5'
UT_FBTUET_RepealFromBankToFuture = '6'
UT_FBTUET_RepealFromFutureToBank = '7'
UT_FBTUET_QueryBankAccount = '8'
UT_FBTUET_QueryFutureAccount = '9'
UT_FBTUET_SignOut = 'A'
UT_FBTUET_SyncKey = 'B'
UT_FBTUET_ReserveOpenAccount = 'C'
UT_FBTUET_CancelReserveOpenAccount = 'D'
UT_FBTUET_ReserveOpenAccountConfirm = 'E'
UT_FBTUET_Other = 'Z'
UT_DBOP_Insert = '0'
UT_DBOP_Update = '1'
UT_DBOP_Delete = '2'
UT_SYNF_Yes = '0'
UT_SYNF_No = '1'
UT_SYNT_OneOffSync = '0'
UT_SYNT_TimerSync = '1'
UT_SYNT_TimerFullSync = '2'
UT_FBEDIR_Settlement = '0'
UT_FBEDIR_Sale = '1'
UT_FBERES_Success = '0'
UT_FBERES_InsufficientBalance = '1'
UT_FBERES_UnknownTrading = '8'
UT_FBERES_Fail = 'x'
UT_FBEES_Normal = '0'
UT_FBEES_ReExchange = '1'
UT_FBEFG_DataPackage = '0'
UT_FBEFG_File = '1'
UT_FBEAT_NotTrade = '0'
UT_FBEAT_Trade = '1'
UT_FBEUET_SignIn = '0'
UT_FBEUET_Exchange = '1'
UT_FBEUET_ReExchange = '2'
UT_FBEUET_QueryBankAccount = '3'
UT_FBEUET_QueryExchDetial = '4'
UT_FBEUET_QueryExchSummary = '5'
UT_FBEUET_QueryExchRate = '6'
UT_FBEUET_CheckBankAccount = '7'
UT_FBEUET_SignOut = '8'
UT_FBEUET_Other = 'Z'
UT_FBERF_UnProcessed = '0'
UT_FBERF_WaitSend = '1'
UT_FBERF_SendSuccess = '2'
UT_FBERF_SendFailed = '3'
UT_FBERF_WaitReSend = '4'
UT_NC_NOERROR = '0'
UT_NC_Warn = '1'
UT_NC_Call = '2'
UT_NC_Force = '3'
UT_NC_CHUANCANG = '4'
UT_NC_Exception = '5'
UT_FCT_Manual = '0'
UT_FCT_Single = '1'
UT_FCT_Group = '2'
UT_RNM_System = '0'
UT_RNM_SMS = '1'
UT_RNM_EMail = '2'
UT_RNM_Manual = '3'
UT_RNS_NotGen = '0'
UT_RNS_Generated = '1'
UT_RNS_SendError = '2'
UT_RNS_SendOk = '3'
UT_RNS_Received = '4'
UT_RNS_Confirmed = '5'
UT_RUE_ExportData = '0'
UT_COST_LastPriceAsc = '0'
UT_COST_LastPriceDesc = '1'
UT_COST_AskPriceAsc = '2'
UT_COST_AskPriceDesc = '3'
UT_COST_BidPriceAsc = '4'
UT_COST_BidPriceDesc = '5'
UT_UOAST_NoSend = '0'
UT_UOAST_Sended = '1'
UT_UOAST_Generated = '2'
UT_UOAST_SendFail = '3'
UT_UOAST_Success = '4'
UT_UOAST_Fail = '5'
UT_UOAST_Cancel = '6'
UT_UOACS_NoApply = '1'
UT_UOACS_Submited = '2'
UT_UOACS_Sended = '3'
UT_UOACS_Success = '4'
UT_UOACS_Refuse = '5'
UT_UOACS_Cancel = '6'
UT_QT_Radio = '1'
UT_QT_Option = '2'
UT_QT_Blank = '3'
UT_BT_Request = '1'
UT_BT_Response = '2'
UT_BT_Notice = '3'
UT_CRC_Success = '0'
UT_CRC_Working = '1'
UT_CRC_InfoFail = '2'
UT_CRC_IDCardFail = '3'
UT_CRC_OtherFail = '4'
UT_CfMMCCT_All = '0'
UT_CfMMCCT_Person = '1'
UT_CfMMCCT_Company = '2'
UT_CfMMCCT_Other = '3'
UT_CfMMCCT_SpecialOrgan = '4'
UT_CfMMCCT_Asset = '5'
UT_EIDT_SHFE = 'S'
UT_EIDT_CZCE = 'Z'
UT_EIDT_DCE = 'D'
UT_EIDT_CFFEX = 'J'
UT_EIDT_INE = 'N'
UT_ECIDT_Hedge = '1'
UT_ECIDT_Arbitrage = '2'
UT_ECIDT_Speculation = '3'
UT_UF_NoUpdate = '0'
UT_UF_Success = '1'
UT_UF_Fail = '2'
UT_UF_TCSuccess = '3'
UT_UF_TCFail = '4'
UT_UF_Cancel = '5'
UT_AOID_OpenInvestor = '1'
UT_AOID_ModifyIDCard = '2'
UT_AOID_ModifyNoIDCard = '3'
UT_AOID_ApplyTradingCode = '4'
UT_AOID_CancelTradingCode = '5'
UT_AOID_CancelInvestor = '6'
UT_AOID_FreezeAccount = '8'
UT_AOID_ActiveFreezeAccount = '9'
UT_ASID_NoComplete = '1'
UT_ASID_Submited = '2'
UT_ASID_Checked = '3'
UT_ASID_Refused = '4'
UT_ASID_Deleted = '5'
UT_UOASM_ByAPI = '1'
UT_UOASM_ByFile = '2'
UT_EvM_ADD = '1'
UT_EvM_UPDATE = '2'
UT_EvM_DELETE = '3'
UT_EvM_CHECK = '4'
UT_EvM_COPY = '5'
UT_EvM_CANCEL = '6'
UT_EvM_Reverse = '7'
UT_UOAA_ASR = '1'
UT_UOAA_ASNR = '2'
UT_UOAA_NSAR = '3'
UT_UOAA_NSR = '4'
UT_EvM_InvestorGroupFlow = '1'
UT_EvM_InvestorRate = '2'
UT_EvM_InvestorCommRateModel = '3'
UT_CL_Zero = '0'
UT_CL_One = '1'
UT_CL_Two = '2'
UT_CHS_Init = '0'
UT_CHS_Checking = '1'
UT_CHS_Checked = '2'
UT_CHS_Refuse = '3'
UT_CHS_Cancel = '4'
UT_CHU_Unused = '0'
UT_CHU_Used = '1'
UT_CHU_Fail = '2'
UT_BAO_ByAccProperty = '0'
UT_BAO_ByFBTransfer = '1'
UT_MBTS_ByInstrument = '0'
UT_MBTS_ByDayInsPrc = '1'
UT_MBTS_ByDayIns = '2'
UT_FTC_BankLaunchBankToBroker = '5'
UT_FTC_BrokerLaunchBankToBroker = '6'
UT_FTC_BankLaunchBrokerToBank = '7'
UT_FTC_BrokerLaunchBrokerToBank = '8'
UT_OTP_NONE = '0'
UT_OTP_TOTP = '1'
UT_OTPS_Unused = '0'
UT_OTPS_Used = '1'
UT_OTPS_Disuse = '2'
UT_BUT_Investor = '1'
UT_BUT_BrokerUser = '2'
UT_FUTT_Commodity = '1'
UT_FUTT_Financial = '2'
UT_FET_Restriction = '0'
UT_FET_TodayRestriction = '1'
UT_FET_Transfer = '2'
UT_FET_Credit = '3'
UT_FET_InvestorWithdrawAlm = '4'
UT_FET_BankRestriction = '5'
UT_FET_Accountregister = '6'
UT_FET_ExchangeFundIO = '7'
UT_FET_InvestorFundIO = '8'
UT_AST_FBTransfer = '0'
UT_AST_ManualEntry = '1'
UT_CST_UnifyAccount = '0'
UT_CST_ManualEntry = '1'
UT_UR_All = '0'
UT_UR_Single = '1'
UT_BG_Investor = '2'
UT_BG_Group = '1'
UT_TSSM_Instrument = '1'
UT_TSSM_Product = '2'
UT_TSSM_Exchange = '3'
UT_ESM_Relative = '1'
UT_ESM_Typical = '2'
UT_RIR_All = '1'
UT_RIR_Model = '2'
UT_RIR_Single = '3'
UT_SDS_Initialize = '0'
UT_SDS_Settlementing = '1'
UT_SDS_Settlemented = '2'
UT_TSRC_NORMAL = '0'
UT_TSRC_QUERY = '1'
UT_FSM_Product = '1'
UT_FSM_Exchange = '2'
UT_FSM_All = '3'
UT_BIR_Property = '1'
UT_BIR_All = '2'
UT_PIR_All = '1'
UT_PIR_Property = '2'
UT_PIR_Single = '3'
UT_FIS_NoCreate = '0'
UT_FIS_Created = '1'
UT_FIS_Failed = '2'
UT_FGS_FileTransmit = '0'
UT_FGS_FileGen = '1'
UT_SoM_Add = '1'
UT_SoM_Update = '2'
UT_SoM_Delete = '3'
UT_SoM_Copy = '4'
UT_SoM_AcTive = '5'
UT_SoM_CanCel = '6'
UT_SoM_ReSet = '7'
UT_SoT_UpdatePassword = '0'
UT_SoT_UserDepartment = '1'
UT_SoT_RoleManager = '2'
UT_SoT_RoleFunction = '3'
UT_SoT_BaseParam = '4'
UT_SoT_SetUserID = '5'
UT_SoT_SetUserRole = '6'
UT_SoT_UserIpRestriction = '7'
UT_SoT_DepartmentManager = '8'
UT_SoT_DepartmentCopy = '9'
UT_SoT_Tradingcode = 'A'
UT_SoT_InvestorStatus = 'B'
UT_SoT_InvestorAuthority = 'C'
UT_SoT_PropertySet = 'D'
UT_SoT_ReSetInvestorPasswd = 'E'
UT_SoT_InvestorPersonalityInfo = 'F'
UT_CSRCQ_Current = '0'
UT_CSRCQ_History = '1'
UT_FRS_Normal = '1'
UT_FRS_Freeze = '0'
UT_STST_Standard = '0'
UT_STST_NonStandard = '1'
UT_RPT_Freeze = '1'
UT_RPT_FreezeActive = '2'
UT_RPT_OpenLimit = '3'
UT_RPT_RelieveOpenLimit = '4'
UT_AMLDS_Normal = '0'
UT_AMLDS_Deleted = '1'
UT_AMLCHS_Init = '0'
UT_AMLCHS_Checking = '1'
UT_AMLCHS_Checked = '2'
UT_AMLCHS_RefuseReport = '3'
UT_AMLDT_DrawDay = '0'
UT_AMLDT_TouchDay = '1'
UT_AMLCL_CheckLevel0 = '0'
UT_AMLCL_CheckLevel1 = '1'
UT_AMLCL_CheckLevel2 = '2'
UT_AMLCL_CheckLevel3 = '3'
UT_EFT_CSV = '0'
UT_EFT_EXCEL = '1'
UT_EFT_DBF = '2'
UT_SMT_Before = '1'
UT_SMT_Settlement = '2'
UT_SMT_After = '3'
UT_SMT_Settlemented = '4'
UT_SML_Must = '1'
UT_SML_Alarm = '2'
UT_SML_Prompt = '3'
UT_SML_Ignore = '4'
UT_SMG_Exhcange = '1'
UT_SMG_ASP = '2'
UT_SMG_CSRC = '3'
UT_LUT_Repeatable = '1'
UT_LUT_Unrepeatable = '2'
UT_DAR_Settle = '1'
UT_DAR_Exchange = '2'
UT_DAR_CSRC = '3'
UT_MGT_ExchMarginRate = '0'
UT_MGT_InstrMarginRate = '1'
UT_MGT_InstrMarginRateTrade = '2'
UT_ACT_Intraday = '1'
UT_ACT_Long = '2'
UT_MRT_Exchange = '1'
UT_MRT_Investor = '2'
UT_MRT_InvestorTrade = '3'
UT_BUS_UnBak = '0'
UT_BUS_BakUp = '1'
UT_BUS_BakUped = '2'
UT_BUS_BakFail = '3'
UT_SIS_UnInitialize = '0'
UT_SIS_Initialize = '1'
UT_SIS_Initialized = '2'
UT_SRS_NoCreate = '0'
UT_SRS_Create = '1'
UT_SRS_Created = '2'
UT_SRS_CreateFail = '3'
UT_SSS_UnSaveData = '0'
UT_SSS_SaveDatad = '1'
UT_SAS_UnArchived = '0'
UT_SAS_Archiving = '1'
UT_SAS_Archived = '2'
UT_SAS_ArchiveFail = '3'
UT_STST_Unkown = '0'
UT_STST_MainCenter = '1'
UT_STST_BackUp = '2'
UT_CDT_Normal = '0'
UT_CDT_SpecFirst = '1'
UT_MFUR_None = '0'
UT_MFUR_Margin = '1'
UT_MFUR_All = '2'
UT_SPT_CzceHedge = '1'
UT_SPT_IneForeignCurrency = '2'
UT_SPT_DceOpenClose = '3'
UT_FMT_Mortgage = '1'
UT_FMT_Redemption = '2'
UT_ASPI_BaseMargin = '1'
UT_ASPI_LowestInterest = '2'
UT_FMD_In = '1'
UT_FMD_Out = '2'
UT_BT_Profit = '0'
UT_BT_Loss = '1'
UT_BT_Other = 'Z'
UT_SST_Manual = '0'
UT_SST_Automatic = '1'
UT_CED_Settlement = '0'
UT_CED_Sale = '1'
UT_CSS_Entry = '1'
UT_CSS_Approve = '2'
UT_CSS_Refuse = '3'
UT_CSS_Revoke = '4'
UT_CSS_Send = '5'
UT_CSS_Success = '6'
UT_CSS_Failure = '7'
UT_REQF_NoSend = '0'
UT_REQF_SendSuccess = '1'
UT_REQF_SendFailed = '2'
UT_REQF_WaitReSend = '3'
UT_RESF_Success = '0'
UT_RESF_InsuffiCient = '1'
UT_RESF_UnKnown = '8'
UT_EXS_Before = '0'
UT_EXS_After = '1'
UT_CR_Domestic = '1'
UT_CR_GMT = '2'
UT_CR_Foreign = '3'
UT_HB_No = '0'
UT_HB_Yes = '1'
UT_SM_Normal = '1'
UT_SM_Emerge = '2'
UT_SM_Restore = '3'
UT_TPT_Full = '1'
UT_TPT_Increment = '2'
UT_TPT_BackUp = '3'
UT_LM_Trade = '0'
UT_LM_Transfer = '1'
UT_CPT_Instrument = '1'
UT_CPT_Margin = '2'
UT_HT_Yes = '1'
UT_HT_No = '0'
UT_AMT_Bank = '1'
UT_AMT_Securities = '2'
UT_AMT_Fund = '3'
UT_AMT_Insurance = '4'
UT_AMT_Trust = '5'
UT_AMT_Other = '9'
UT_CFIOT_FundIO = '0'
UT_CFIOT_SwapCurrency = '1'
UT_CAT_Futures = '1'
UT_CAT_AssetmgrFuture = '2'
UT_CAT_AssetmgrTrustee = '3'
UT_CAT_AssetmgrTransfer = '4'
UT_LT_Chinese = '1'
UT_LT_English = '2'
UT_AMCT_Person = '1'
UT_AMCT_Organ = '2'
UT_AMCT_SpecialOrgan = '4'
UT_ASST_Futures = '3'
UT_ASST_SpecialOrgan = '4'
UT_CIT_HasExch = '0'
UT_CIT_HasATP = '1'
UT_CIT_HasDiff = '2'
UT_DT_HandDeliv = '1'
UT_DT_PersonDeliv = '2'
UT_MMSA_NO = '0'
UT_MMSA_YES = '1'
UT_CACT_Person = '0'
UT_CACT_Company = '1'
UT_CACT_Other = '2'
UT_UOAAT_Futures = '1'
UT_UOAAT_SpecialOrgan = '2'
UT_DEN_Buy = '0'
UT_DEN_Sell = '1'
UT_OFEN_Open = '0'
UT_OFEN_Close = '1'
UT_OFEN_ForceClose = '2'
UT_OFEN_CloseToday = '3'
UT_OFEN_CloseYesterday = '4'
UT_OFEN_ForceOff = '5'
UT_OFEN_LocalForceClose = '6'
UT_HFEN_Speculation = '1'
UT_HFEN_Arbitrage = '2'
UT_HFEN_Hedge = '3'
UT_FIOTEN_FundIO = '1'
UT_FIOTEN_Transfer = '2'
UT_FIOTEN_SwapCurrency = '3'
UT_FTEN_Deposite = '1'
UT_FTEN_ItemFund = '2'
UT_FTEN_Company = '3'
UT_FTEN_InnerTransfer = '4'
UT_FDEN_In = '1'
UT_FDEN_Out = '2'
UT_FMDEN_In = '1'
UT_FMDEN_Out = '2'
UT_CP_CallOptions = '1'
UT_CP_PutOptions = '2'
UT_STM_Continental = '0'
UT_STM_American = '1'
UT_STM_Bermuda = '2'
UT_STT_Hedge = '0'
UT_STT_Match = '1'
UT_APPT_NotStrikeNum = '4'
UT_GUDS_Gen = '0'
UT_GUDS_Hand = '1'
UT_OER_NoExec = 'n'
UT_OER_Canceled = 'c'
UT_OER_OK = '0'
UT_OER_NoPosition = '1'
UT_OER_NoDeposit = '2'
UT_OER_NoParticipant = '3'
UT_OER_NoClient = '4'
UT_OER_NoInstrument = '6'
UT_OER_NoRight = '7'
UT_OER_InvalidVolume = '8'
UT_OER_NoEnoughHistoryTrade = '9'
UT_OER_Unknown = 'a'
UT_COMBT_Future = '0'
UT_COMBT_BUL = '1'
UT_COMBT_BER = '2'
UT_COMBT_STD = '3'
UT_COMBT_STG = '4'
UT_COMBT_PRT = '5'
UT_COMBT_CLD = '6'
UT_ORPT_PreSettlementPrice = '1'
UT_ORPT_OpenPrice = '4'
UT_BLAG_Default = '1'
UT_BLAG_IncludeOptValLost = '2'
UT_ACTP_Exec = '1'
UT_ACTP_Abandon = '2'
UT_FQST_Submitted = 'a'
UT_FQST_Accepted = 'b'
UT_FQST_Rejected = 'c'
UT_VM_Absolute = '0'
UT_VM_Ratio = '1'
UT_EOPF_Reserve = '0'
UT_EOPF_UnReserve = '1'
UT_EOCF_AutoClose = '0'
UT_EOCF_NotToClose = '1'
UT_PTE_Futures = '1'
UT_PTE_Options = '2'
UT_CUFN_CUFN_O = 'O'
UT_CUFN_CUFN_T = 'T'
UT_CUFN_CUFN_P = 'P'
UT_CUFN_CUFN_N = 'N'
UT_CUFN_CUFN_L = 'L'
UT_CUFN_CUFN_F = 'F'
UT_CUFN_CUFN_C = 'C'
UT_CUFN_CUFN_M = 'M'
UT_DUFN_DUFN_O = 'O'
UT_DUFN_DUFN_T = 'T'
UT_DUFN_DUFN_P = 'P'
UT_DUFN_DUFN_F = 'F'
UT_DUFN_DUFN_C = 'C'
UT_DUFN_DUFN_D = 'D'
UT_DUFN_DUFN_M = 'M'
UT_DUFN_DUFN_S = 'S'
UT_SUFN_SUFN_O = 'O'
UT_SUFN_SUFN_T = 'T'
UT_SUFN_SUFN_P = 'P'
UT_SUFN_SUFN_F = 'F'
UT_CFUFN_SUFN_T = 'T'
UT_CFUFN_SUFN_P = 'P'
UT_CFUFN_SUFN_F = 'F'
UT_CFUFN_SUFN_S = 'S'
UT_CMDR_Comb = '0'
UT_CMDR_UnComb = '1'
UT_STOV_RealValue = '1'
UT_STOV_ProfitValue = '2'
UT_STOV_RealRatio = '3'
UT_STOV_ProfitRatio = '4'
UT_ROAST_Processing = '0'
UT_ROAST_Cancelled = '1'
UT_ROAST_Opened = '2'
UT_ROAST_Invalid = '3'
UT_TRCL_Trade = '1'
UT_TRCL_MD = '2'
UT_BZTP_Option = '1'
UT_BZTP_Stock = '2'
UT_BZTP_Credit = '3'
UT_DSTP_Register = '1'
UT_DSTP_Cancel = '2'
UT_TRET_Trade = '1'
UT_TRET_Cancel = '2'
UT_TRET_BuyTrade = 'B'
UT_TRET_SellTrade = 'S'
UT_RSRT_Login = '1'
UT_ACCT_Option = '1'
UT_ACCT_Stock = '2'
UT_ACCT_Credit = '3'
UT_TM_T0 = '0'
UT_TM_T1 = '1'
UT_SDT_L2DepthMarketData = 0x01
UT_SDT_L2BestOrder = 0x02
UT_SDT_L2Trade = 0x04
UT_SDT_L2Order = 0x08
UT_EXG_SSE = '1'
UT_EXG_SZSE = '2'
UT_EXG_SHFE = '3'
UT_EXG_CFFEX = '4'
UT_EXG_DCE = '5'
UT_EXG_CZCE = '6'
UT_EXG_INE = '7'
UT_EXG_HKEX = '8'
UT_EXG_OTHER = 'z'
UT_BSF_Unknown = 'N'
UT_BSF_Buy = 'B'
UT_BSF_Sell = 'S'
UT_CCT_Single = '1'
UT_CCT_Underlying = '2'
UT_CCT_Group = '3'
UT_SSF_Forbidden = '0'
UT_SSF_Allowed = '1'
UT_SSF_Necessary = '2'
UT_SSF_OtherNecessary = '3'
UT_DSS_Submitted = 'a'
UT_DSS_Accepted = 'b'
UT_DSS_Rejected = 'c'
UT_DSS_Canceled = 'd'
UT_CTB_ALL = '*'
UT_CTB_Collateral = '1'
UT_CTB_CreditFund = '2'
UT_CTB_CollateralIn = '3'
UT_CTB_WarrentExtension = '4'
UT_CTB_CreditStock = '5'
UT_LCKT_Lock = '1'
UT_LCKT_Unlock = '2'
UT_FRRS_Init = '1'
UT_FRRS_Lock = '2'
UT_FRRS_CoveredOrder = '3'
UT_FRRS_Exec = '4'
UT_FRRS_Check = '5'
UT_FRRS_ExecFreeze = '6'
UT_FZTP_Request = '1'
UT_FZTP_Force = '4'
